.. include:: ../README.rst
    :end-before: inclusion-end-marker

Contents
--------

.. toctree::
   :maxdepth: 2

   quickstart
   integrations
   tips
   configuration
   limitations
   how_it_works
   contributing
